function param = prtr(modelname, paraname)
%  sets parameter transformation type and arguments
% /********************************************************************
% **   Each row has the following specification:
% **
% **    tr~a~b~c
% **
% **    tr parameter transformation type
% **        0: no transformation needed
% **        1: [a,b] -> [-1,1] -> [-inf,inf] by (1/c)*c*z/sqrt(1-c*z^2)
% **        2: [0,inf] -> [-inf,inf] by b + (1/c)*ln(para[i]-a);
% **    a  transformation argument a (usually lower bound)
% **    b  transformation argument b (usually upper bound)
% **    c  transformation argument c
% ********************************************************************/
if strcmp(modelname, 'NKASGAPlog_')
    % transformation
    tau   = [2 , 1e-5  , 10      , 1];
    nu    = [1 , 1e-5  , 0.99999 , 1];
    phi   = [2 , 1e-5  , 1000     , 1];
    cyst  = [1 , 1e-5  , 0.99999 , 1];
    psi1  = [2 , 0.1   , 10      , 1];
    psi2  = [2 , 1e-5  , 10      , 1];
    rhor  = [1 , 1e-5  , 0.99999 , 1];
    rhog  = [1 , 1e-5  , 0.99999 , 1];
    rhoz  = [1 , 1e-5  , 0.99999 , 1];
    rrst  = [2 , 1e-5  , 10      , 1];
    pist  = [2 , 1e-5  , 20      , 1];
    gamst = [0 , -5    , 5       , 1];
    sigr  = [2 , 1e-8  , 5       , 1];
    sigg  = [2 , 1e-8  , 5       , 1];
    sigz  = [2 , 1e-8  , 5       , 1];
    % for measurement shocks
    sigmy = [2 , 1e-8  , 5       , 1];
    sigmp = [2 , 1e-8  , 5       , 1];
    sigmr = [2 , 1e-8  , 5       , 1];
    
else
    disp('prtr: no modelname');
end

% assign values
npara = size(paraname,1);
param = nan*ones(npara,4);
for i=1:1:npara;
    eval(['param(', num2str(i),',:) = ', paraname{i}, ';']);
end




