function show_mh(mh_para, option, pnames, mh_fval)
% option
% 1: time-series plot
% 2: ksdensity
% 3: autocorrelation function
% 4: cumulative mean
% 5: condtional expectation of posterior distribution

% info
[nsim, npara] = size(mh_para);

if nargin <3
    % load pnames
    try
        [a, pnames] = psel([],[]);
    catch
        pnames = cell(npara,1);
    end
end

if nargin <4
    mh_fval = [];
end

if (option == 5) && isempty(mh_fval)
    disp('Error: option 5 requires mh_fval');
    return
end
    



% draw pictures
nfigures = ceil(npara/12);

% time-series plot
if option==1
    plot_ind = 1;
    for fig_ind = 1:1:nfigures
        %eval(['figure(', num2str(fig_ind),');']);
        figure;
        for subplot_ind = 1:1:12;
            subplot(3,4, subplot_ind);
            plot(mh_para(:,plot_ind))
            title(pnames{plot_ind});
            if plot_ind == npara
                break
            end
            plot_ind = plot_ind + 1;
        end
    end
elseif option == 2
    plot_ind = 1;
    for fig_ind = 1:1:nfigures
        % eval(['figure(', num2str(fig_ind),');']);
        figure
        for subplot_ind = 1:1:12;
            subplot(3,4, subplot_ind);
            ksdensity(mh_para(:,plot_ind))
            title(pnames{plot_ind});
            if plot_ind == npara
                break
            end
            plot_ind = plot_ind + 1;
        end
    end
elseif option == 3
    plot_ind = 1;
    for fig_ind = 1:1:nfigures
        %eval(['figure(', num2str(fig_ind),');']);
        figure
        for subplot_ind = 1:1:12;
            subplot(3,4, subplot_ind);
            autocorr(mh_para(:,plot_ind),500)
            title(pnames{plot_ind});
            if plot_ind == npara
                break
            end
            plot_ind = plot_ind + 1;
        end
    end
elseif option == 4
    
    plot_ind = 1;
    temp_cummean = (cumsum(mh_para(1:nsim,:))./((1:1:nsim)'*ones(1,npara)));
    for fig_ind = 1:1:nfigures
        %eval(['figure(', num2str(fig_ind),');']);
        figure
        for subplot_ind = 1:1:12;
            subplot(3,4, subplot_ind);
            plot(temp_cummean(:,plot_ind));
            title(pnames{plot_ind});
            if plot_ind == npara
                break
            end
            plot_ind = plot_ind + 1;
        end
    end
    
elseif option == 5
    
    for_n = 50;
    temp_para = forevery(mh_para, for_n);
    temp_fval = forevery(mh_fval, for_n);
    
    plot_ind = 1;
    for fig_ind = 1:1:nfigures
        %eval(['figure(', num2str(fig_ind),');']);
        figure
        for subplot_ind = 1:1:12;
            subplot(3,4, subplot_ind);
            scatter(temp_para(:,plot_ind), temp_fval)
            hold on
            r=ksrlin(temp_para(:,plot_ind),temp_fval,mean(temp_para(:,plot_ind)/20));
            plot(r.x, r.f, 'r', 'linewidth', 2);
            hold off
            title(pnames{plot_ind});
            if plot_ind == npara
                break
            end
            plot_ind = plot_ind + 1;
        end
    end
    
    
end
end



